@@ -1,5 +1,5 @@
 from livestreamer.compat import str, bytes, parse_qs
-from livestreamer.plugins import Plugin, PluginError, NoStreamsError, register_plugin
+from livestreamer.plugins import Plugin, PluginError, NoStreamsError
 from livestreamer.stream import HTTPStream
 from livestreamer.utils import urlget, verifyjson
 
@@ -12,20 +12,21 @@ class Youtube(Plugin):
         return "youtube.com" in url
 
     def _get_stream_info(self, url):
-        data = urlget(url)
+        res = urlget(url)
+        data = res.text
         config = None
 
-        match = re.search(b"'PLAYER_CONFIG': (.+)\n.+}\);", data)
+        match = re.search("'PLAYER_CONFIG': (.+)\n.+}\);", data)
         if match:
             config = match.group(1)
 
-        match = re.search(b"yt.playerConfig = (.+)\;\n", data)
+        match = re.search("yt.playerConfig = (.+)\;\n", data)
         if match:
             config = match.group(1)
 
         if config:
             try:
-                parsed = json.loads(str(config, "utf8"))
+                parsed = json.loads(config)
             except ValueError as err:
                 raise PluginError(("Unable to parse config JSON: {0})").format(err))
 
@@ -76,7 +77,7 @@ class Youtube(Plugin):
             if not "url" in streaminfo:
                 continue
 
-            stream = HTTPStream(streaminfo["url"][0])
+            stream = HTTPStream(self.session, streaminfo["url"][0])
 
             if streaminfo["itag"][0] in formatmap:
                 quality = formatmap[streaminfo["itag"][0]]
@@ -87,4 +88,4 @@ class Youtube(Plugin):
 
         return streams
 
-register_plugin("youtube", Youtube)
+__plugin__ = Youtube
